@@ -44,13 +44,13 @@ readHB <- function(file)
     valln <- as.integer(substr(hdr[2], 43, 56))
     rhsln <- as.integer(substr(hdr[2], 57, 70))
     if (!(t1 <- substr(hdr[3], 1, 1)) %in% c('C', 'R', 'P'))
-	stop("Invalid storage type: ", t1)
+	stop(gettextf("Invalid storage type: %s", t1), domain=NA)
     if (t1 != 'R') stop("Only numeric sparse matrices allowed")
     ## _FIXME: Patterns should also be allowed
     if (!(t2 <- substr(hdr[3], 2, 2)) %in% c('H', 'R', 'S', 'U', 'Z'))
-	stop("Invalid storage format: ", t2)
+	stop(gettextf("Invalid storage format: %s", t2), domain=NA)
     if (!(t3 <- substr(hdr[3], 3, 3)) %in% c('A', 'E'))
-	stop("Invalid assembled indicator: ", t3)
+	stop(gettextf("Invalid assembled indicator: %s", t3), domain=NA)
     nr <- as.integer(substr(hdr[3], 15, 28))
     nc <- as.integer(substr(hdr[3], 29, 42))
     nz <- as.integer(substr(hdr[3], 43, 56))
