@@ -71,7 +71,7 @@ setMethod("rcond", signature(x = "dtrMatrix", norm = "missing"),
 
 setMethod("chol2inv", signature(x = "dtrMatrix"),
 	  function (x, ...) {
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      if (x@diag != "N") x <- diagU2N(x)
 	      .Call(dtrMatrix_chol2inv, x)
 	  })
@@ -79,31 +79,31 @@ setMethod("chol2inv", signature(x = "dtrMatrix"),
 setMethod("solve", signature(a = "dtrMatrix", b="missing"),
 	  function(a, b, ...) {
 	      ## warn, as e.g. CHMfactor have 'system' as third argument
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      .Call(dtrMatrix_solve, a)
 	  }, valueClass = "dtrMatrix")
 
 setMethod("solve", signature(a = "dtrMatrix", b="ddenseMatrix"),
 	  function(a, b, ...) {
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      .Call(dtrMatrix_matrix_solve, a, b)
 	  }, valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dtrMatrix", b="dMatrix"),
 	  function(a, b, ...) {
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      .Call(dtrMatrix_matrix_solve, a, as(b,"denseMatrix"))
 	  }, valueClass = "dgeMatrix")
 setMethod("solve", signature(a = "dtrMatrix", b="Matrix"),
 	  function(a, b, ...) {
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      .Call(dtrMatrix_matrix_solve, a, as(as(b, "dMatrix"),
 						  "denseMatrix"))
 	  }, valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dtrMatrix", b="matrix"),
 	  function(a, b, ...) {
-	      chk.s(...)
+	      chk.s(..., which.call=-2)
 	      .Call(dtrMatrix_matrix_solve, a, b)
 	  }, valueClass = "dgeMatrix")
 
