@@ -108,7 +108,7 @@ SEXP dsyMatrix_as_matrix(SEXP from, SEXP keep_dimnames)
 
 SEXP dsyMatrix_matrix_mm(SEXP a, SEXP b, SEXP rtP)
 {
-    SEXP val = PROTECT(dup_mMatrix_as_dgeMatrix(b));
+    SEXP val = PROTECT(dup_mMatrix_as_dgeMatrix(b));// incl. its dimnames
     int rt = asLogical(rtP); /* if(rt), compute b %*% a,  else  a %*% b */
     int *adims = INTEGER(GET_SLOT(a, Matrix_DimSym)),
 	*bdims = INTEGER(GET_SLOT(val, Matrix_DimSym)),
@@ -120,12 +120,18 @@ SEXP dsyMatrix_matrix_mm(SEXP a, SEXP b, SEXP rtP)
 
     if ((rt && n != adims[0]) || (!rt && m != adims[0]))
 	error(_("Matrices are not conformable for multiplication"));
-    if (m < 1 || n < 1) {
-/* 	error(_("Matrices with zero extents cannot be multiplied")); */
-    } else
+    if (m >=1 && n >= 1)
 	F77_CALL(dsymm)(rt ? "R" :"L", uplo_P(a), &m, &n, &one,
 			REAL(GET_SLOT(a, Matrix_xSym)), adims, bcp,
 			&m, &zero, vx, &m);
+    // add dimnames:
+    if(rt) { // v <- b %*% a : rownames(v) == rownames(b)  are already there
+	SET_VECTOR_ELT(GET_SLOT(val, Matrix_DimNamesSym), 1,
+		duplicate(VECTOR_ELT(GET_SLOT(a, Matrix_DimNamesSym), 1)));
+    } else { // v <- a %*% b : colnames(v) == colnames(b)  are already there
+	SET_VECTOR_ELT(GET_SLOT(val, Matrix_DimNamesSym), 0,
+		duplicate(VECTOR_ELT(GET_SLOT(a, Matrix_DimNamesSym), 0)));
+    }
     UNPROTECT(1);
     return val;
 }
@@ -160,6 +166,7 @@ SEXP dsyMatrix_trf(SEXP x)
     return set_factors(x, val, "BunchKaufman");
 }
 
+// this is very close to lsyMatrix_as_lsp*() in ./ldense.c  -- keep synced !
 SEXP dsyMatrix_as_dspMatrix(SEXP from)
 {
     SEXP val = PROTECT(NEW_OBJECT(MAKE_CLASS("dspMatrix"))),
@@ -171,7 +178,7 @@ SEXP dsyMatrix_as_dspMatrix(SEXP from)
     SET_SLOT(val, Matrix_uploSym, duplicate(uplo));
     full_to_packed_double(
 	REAL(ALLOC_SLOT(val, Matrix_xSym, REALSXP, (n*(n+1))/2)),
-	REAL(GET_SLOT(from, Matrix_xSym)), n,
+	REAL( GET_SLOT(from, Matrix_xSym)), n,
 	*CHAR(STRING_ELT(uplo, 0)) == 'U' ? UPP : LOW, NUN);
     SET_SLOT(val, Matrix_DimNamesSym,
 	     duplicate(GET_SLOT(from, Matrix_DimNamesSym)));
